@@ -16,8 +16,8 @@ DB_PASS = os.environ.get("MEDIAN_DB_PASS", "root")
 DB_NAME = os.environ.get("MEDIAN_DB_NAME", "test")
 
 
-DB_TABLE = "v_emplacements"
-DB_MODEL = "emplacements"
+DB_TABLE = "f_liste"
+DB_MODEL = "FListe"
 
 TYPE_FIELD = []
 
@@ -31,8 +31,8 @@ print("from peewee import SQL\n")
 print("from ..base import BaseModel\n\n")
 
 Query = """
-SELECT `TABLE_NAME` AS table_name, `COLUMN_NAME` AS column_name, `ORDINAL_POSITION` AS column_order, `COLUMN_DEFAULT` AS column_defaut, 
-       `IS_NULLABLE` AS can_be_null, `DATA_TYPE` AS column_datatype, `CHARACTER_MAXIMUM_LENGTH` AS column_length, `NUMERIC_PRECISION` AS  num_prec, 
+SELECT `TABLE_NAME` AS table_name, `COLUMN_NAME` AS column_name, `ORDINAL_POSITION` AS column_order, `COLUMN_DEFAULT` AS column_defaut,
+       `IS_NULLABLE` AS can_be_null, `DATA_TYPE` AS column_datatype, `CHARACTER_MAXIMUM_LENGTH` AS column_length, `NUMERIC_PRECISION` AS  num_prec,
        `NUMERIC_SCALE` AS num_scale, `DATETIME_PRECISION` AS date_prec, `COLUMN_KEY` AS column_key, `EXTRA` AS extra, `COLUMN_COMMENT` AS column_comment,
        `COLUMN_TYPE` AS column_type
 FROM information_schema.`COLUMNS`
@@ -67,10 +67,15 @@ try:
                 col_type = "IntegerField"
         elif row["column_datatype"] == "varchar":
             col_type = "CharField"
+            if row['column_length'] > 0:
+                col_attrs.append("""max_length=%s""" % row['column_length'])
             if row["column_defaut"] is not None:
                 col_attrs.append(
                     """constraints=[SQL("DEFAULT '%s'")]""" % row["column_defaut"]
                 )
+                col_attrs.append(
+                    """default='%s'""" % row["column_defaut"]
+                )
         elif row["column_datatype"] == "text":
             col_type = "TextField"
             if row["column_defaut"] is not None:
@@ -106,6 +111,9 @@ try:
                 col_attrs.append(
                     """constraints=[SQL("DEFAULT %s")]""" % row["column_defaut"]
                 )
+                col_attrs.append(
+                    """default=%s""" % row["column_defaut"]
+                )
         else:
             print(row)
         print(
