@@ -13,7 +13,7 @@ def check_auth(user, passwd):
     return True if correct
     """
     try:
-        usr = User.get(username=user, password=crypte(passwd))
+        User.get(username=user, password=crypte(passwd))
         logger.info('User "%s" found' % user)
     except DoesNotExist:
         logger.warning('User"%s" not found!' % user)
@@ -29,7 +29,7 @@ def check_badge(badge):
     return True if correct
     """
     try:
-        usr = User.get(badge=badge)
+        User.get(badge=badge)
         logger.info('Badge "%s" found' % badge)
     except DoesNotExist:
         logger.warning('Badge "%s" not found!' % badge)
