@@ -11,6 +11,7 @@ class TypeServiListe(Enum):
     GlobalePilulier = 'GLOBAL_PIL'
     Nominatif = 'NOMINATIF'
     Exotique = 'EXOTIQUE'
+    RiedlBoite = 'RIEDL_BTE'     # Riedl mode
     Retour = 'RETOUR'            # Riedl mode
     Prelevement = 'PRELEVEMENT'  # Riedl mode
     RetraitLot = 'RETRAIT'       # Riedl mode
@@ -37,3 +38,9 @@ CUSTOM_PROFILS = [
     'REFERENT',
     'INFIRMIER'
 ]
+
+RIEDL_PRIORITY = [
+    (1, 'Haute'),
+    (3, 'Normale'),
+    (5, 'Faible'),
+]
