@@ -61,7 +61,10 @@ class Stock(BaseModel):
         column_name="x_reinteg", null=True, constraints=[SQL("DEFAULT 0")]
     )
     # manquant = BooleanField(column_name="x_manquant", constraints=[SQL("DEFAULT 0")])
-    ucd = CharField(column_name="x_ucd", constraints=[SQL("DEFAULT ''")])
+    ucd = CharField(
+        column_name="x_ucd", max_length=13, constraints=[SQL("DEFAULT ''")], default='')
+    cip = CharField(
+        column_name='x_cip', max_length=13, constraints=[SQL("DEFAULT ''")], default='')
     # etat = CharField(column_name="x_etat", constraints=[SQL("DEFAULT ''")])
     serial = CharField(column_name="x_serial", constraints=[SQL("DEFAULT ''")])
     zone_admin = CharField(column_name="x_zone_admin", constraints=[SQL("DEFAULT ''")])
@@ -70,3 +73,19 @@ class Stock(BaseModel):
 
     class Meta:
         table_name = "f_stock"
+
+
+class CodeBlocage(BaseModel):
+
+    pk = AutoField(
+        column_name='x_pk', primary_key=True)
+    valeur = IntegerField(
+        column_name='x_valeur', constraints=[SQL("DEFAULT 0")], default=0)
+    libelle = CharField(
+        column_name='x_libelle', max_length=250, constraints=[SQL("DEFAULT ''")], default='')
+
+    class Meta:
+        table_name = 'f_defaut'
+        indexes = (
+            (('x_valeur',), True)
+        )
