@@ -1,7 +1,8 @@
-from peewee import IntegerField, CharField, DateTimeField, BooleanField
+from peewee import IntegerField, CharField, DateTimeField
 from ..base import BaseModelSuiviProd
 from peewee import SQL
 
+
 class SuiviProd(BaseModelSuiviProd):
 
     pk = IntegerField(
